/*
 * Copyright (C) 2023  Valentin Lorentz
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use super::Component;
use color_eyre::eyre::{Result, WrapErr};
use ratatui::{prelude::*, widgets::*};

use crate::widgets::{BottomAlignedParagraph, OverlappableWidget};

#[derive(Default)]
pub struct Backlog {}

impl Component for Backlog {
  fn draw(
    &mut self,
    frame: &mut Frame<'_>,
    area: Rect,
    buffers: &crate::buffers::Buffers,
  ) -> Result<()> {
    let block = Block::new().borders(Borders::ALL);
    let mut text_area = block.inner(area);
    block.render(area, frame.buffer_mut());

    let mut items = buffers.active_buffer().content();
    items.reverse();
    for item in items {
      let widget = BottomAlignedParagraph::new(item);
      let height = widget.render_overlap(text_area, frame.buffer_mut());
      assert!(area.height >= height, "{:?} {}", area, height);
      text_area.height -= height; // Remove lines at the bottom used by this paragraph
    }
    Ok(())
  }
}
